*Creación de mapas
*Utilizar la base de la GEIH
use "$Datos/2010-2018.dta"

*Crear los id correspondientes al mapa para las 23 ciudades

gen id=.			
replace id=	378	if area==	5
replace id=	10	if area==	8
replace id=	723	if area==	11
replace id=	37	if area==	13
replace id=	534	if area==	15
replace id=	640	if area==	17
replace id=	970	if area==	18
replace id=	941	if area==	19
replace id=	22	if area==	20
replace id=	146	if area==	23
replace id=	387	if area==	27
replace id=	898	if area==	41
replace id=	4	if area==	44
replace id=	6	if area==	47
replace id=	816	if area==	50
replace id=	1033	if area==	52
replace id=	180	if area==	54
replace id=	773	if area==	63
replace id=	710	if area==	66
replace id=	258	if area==	68
replace id=	104	if area==	70
replace id=	756	if area==	73
replace id=	879	if area==	76


*Colapsar las estadísticas descriptivas que queremos ver en los mapas. ///
*Queremos la tasa de desempleo, participación e informalidad. ///
*También los salarios relaes y las horas de trabajo no remunerado, todos para cada año y género. ///
*Reorganizamos la base para que cada observación represente el valor de cada variable_género_año ///
*para cada ciudad. Este proceso crea dos bases de datos que serán anexadas al archivo del mapa.

foreach j in 2010 2018{
preserve
collapse(mean) d pea e salario_real informalidad hog_norem nino_norem ///
[fweight=int(peso_anio)] if id!=. & anio==`j', by(id genero)
 reshape wide d e hog_norem informalidad nino_norem pea salario_real, i(id) j(genero)
 
 foreach i in d1 d2 e1 e2 hog_norem1 hog_norem2 informalidad1 informalidad2 nino_norem1 ///
 nino_norem2 pea1 pea2 salario_real1 salario_real2 {
 rename `i' `i'_`j'
 }
 save "$mapas/collapse_`j'.dta",replace
restore
}

save "$Datos/2010-2018.dta", replace


*Convertir el mapa "mpio.shp" en una base de datos "dbCol3", una de coordenadas "coCol3" ///
*con los respectivos identificadores "id" y coordenadas para las etiquetas "c".
cd "$mapas"
ssc install spmap
ssc install shp2dta 
shp2dta using mpio.shp, database (dbCol3) coordinates (coCol3) genid (id) genc(c)
use dbCol3, clear

*Juntar la base del mapa con las dos que creamos anteriormente
merge 1:1 id using "$mapas/collapse_2010.dta"
drop _merge
merge 1:1 id using "$mapas/collapse_2018.dta"


*Crear una variable "mpio" para las etiquetas de las ciudades según su identificador
gen mpio=.	
tostring mpio,replace		
replace mpio=	"Medellín"	if id==	378
replace mpio=	"Barranquilla"	if id==	10
replace mpio=	"Bogotá"	if id==	723
replace mpio=	"Cartagena"	if id==	37
replace mpio=	"Tunja"	if id==	534
replace mpio=	"Manizales"	if id==	640
replace mpio=	"Florencia"	if id==	970
replace mpio=	"Popayán"	if id==	941
replace mpio=	"Valledupar"	if id==	22
replace mpio=	"Montería"	if id==	146
replace mpio=	"Quibdó"	if id==	387
replace mpio=	"Neiva"	if id==	898
replace mpio=	"Riohacha"	if id==	4
replace mpio=	"Santa Marta"	if id==	6
replace mpio=	"Villavicencio"	if id==	816
replace mpio=	"Pasto"	if id==	1033
replace mpio=	"Cúcuta"	if id==	180
replace mpio=	"Armenia"	if id==	773
replace mpio=	"Pereira"	if id==	710
replace mpio=	"Bucaramanga"	if id==	258
replace mpio=	"Sincelejo"	if id==	104
replace mpio=	"Ibagué"	if id==	756
replace mpio=	"Cali"	if id==	879
replace mpio="" if mpio=="."

*Guardar la base
save "dbCol3.dta", replace

*Este comando permite utilizar el borde del mapa del país de manera ///
*independiente, para ponerle colores o márgenes distintos
ssc install mergepoly
mergepoly id using coCol3, coord("col_coord.dta") replace
use "dbCol3.dta", clear



*La variable que queremos colorear en el mapa serán las brechas de género ///
*en puntos porcentuales.

*La tasa de desempleo e informalidad y las horas de trabajo no remunerado ///
*suele ser mayor para las mujeres, por lo que su ///
*brecha es el valor para mujeres menos el valor para hombres 
foreach i in 2010 2018 {
foreach j in d hog_norem informalidad nino_norem {
gen br_`j'_`i'=`j'2_`i'-`j'1_`i'
}
}

*Para las tasas de ocupación y participación, se hace al revés, pues suelen ///
*ser mayores para los hombres. 
foreach i in 2010 2018 {
foreach j in e pea {
gen br_`j'_`i'=`j'1_`i'-`j'2_`i'
}
}



*Crear la brecha salarial relativa a los ingresos de los hombres (%)
foreach i in 2010 2018 {
gen br_salario_real_`i'=(salario_real1_`i'-salario_real2_`i')/salario_real1_`i'
}

*Darle un formato de dos decimales a las variables
format (br_d_2010 br_d_2018 br_e_2010 br_e_2018 br_hog_norem_2010 br_hog_norem_2018 ///
br_informalidad_2010 br_informalidad_2018 br_nino_norem_2010 br_nino_norem_2018 br_pea_2010 ///
br_pea_2018 br_salario_real_2010 br_salario_real_2018 d1_2010 d1_2018 d2_2010 d2_2018 e1_2010 ///
e1_2018 e2_2010 e2_2018 hog_norem1_2010 hog_norem1_2018 hog_norem2_2010 hog_norem2_2018 ///
 informalidad1_2010 informalidad1_2018 informalidad2_2010 informalidad2_2018 nino_norem1_2010 ///
 nino_norem1_2018 nino_norem2_2010 nino_norem2_2018 pea1_2010 pea1_2018 pea2_2010 pea2_2018 ///
 salario_real1_2010 salario_real1_2018 salario_real2_2010 salario_real2_2018) %12.2f


*Generar etiquetas de los municipios con las brechas
foreach i in d e hog_norem informalidad nino_norem pea salario_real {
foreach j in 2010 2018 {
egen br_mpio_`i'_`j'=concat(mpio br_`i'_`j' ),punct(" ") f(%12.2f)
 replace br_mpio_`i'_`j'="" if br_mpio_`i'_`j'=="."
}
} 
 
 
*Definir el comando ereplace para hacer replace con egen
do "$Datos/ereplace.do"
 
*Generar etiquetas de los municipios con los valores de las variables para hombres y mujeres 
foreach i in d e hog_norem informalidad nino_norem pea salario_real {
foreach j in 2010 2018 {
egen mpio_niveles_`i'_`j'=concat(mpio `i'1_`j'), punct(" H:") f(%12.2f)
ereplace mpio_niveles_`i'_`j'=concat(mpio_niveles_`i'_`j' `i'2_`j'), punct(" M:") f(%12.2f)
replace mpio_niveles_`i'_`j'="" if mpio_niveles_`i'_`j'=="H:. M:."
}
}  

*Nuevas variables de coordenadas para correr etiquetas
gen x_c_l=x_c
gen y_c_l=y_c

*Correr etiquetas
*Quibdó
replace x_c_l = 740433.13 in 387
*Bogotá
replace y_c_l = 985655.5 in 723
*Villavicencio
replace x_c_l = 1085457.3 in 816
*Neiva
replace y_c_l = 844527.75 in 898
*Armenia
replace x_c_l = 720702 in 773
*Ibagué
replace y_c_l = 995104.06 in 756
*Pereira
replace x_c_l = 830667.44 in 710
*Montería
replace x_c_l = 803347.5 in 146
*Barranquilla
replace y_c_l = 1736112.5 in 10
replace x_c_l = 890324.31 in 10
*Santa Marta
replace y_c_l = 1759959.6 in 6
replace x_c_l = 997949.8 in 6
*Valledupar
replace x_c_l = 961656 in 22
*Riohacha
replace y_c_l = 1775882.8 in 4

 
 save "dbCol3.dta", replace
